Βπ»ββοΈπͺ azalia-remi
azalia-remi adds a unified storage service on top of remi-rs for allow configuring multiple storage services but only uses one from what the end user wants.
This uses Cargoβs crate features to implicitilly allow you to pick out which Remi-based crates to implement
into your applications. You can use the features = ["all"] in your Cargo.tomlβs definition of azalia-remi
to include all crates.
ΒExample
// Cargo.toml:
//
// [dependencies]
// tokio = { version = "*", features = ["full"] }
// azalia-remi = { version = "^0", features = ["fs"] }
use azalia_remi::{
StorageService,
Config,
core::StorageService as _,
fs
};
let config = fs::StorageConfig {
directory: "/data".into(),
};
let service = StorageService::Filesystem(fs::StorageService::with_config(config));
service.init().await.unwrap(); // initialize the fs version of remi
// do whatever you wantRe-exportsΒ
pub use remi as core;pub use remi_gridfs as gridfs;gridfspub use remi_azure as azure;azurepub use remi_s3 as s3;s3pub use remi_fs as fs;fs
EnumsΒ
- Config
- Error
- Error variant when using methods from
StorageService. - Storage
Service - Represents a unified
StorageServicethat can be either the following: